pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Robert Treat <xzilla@users.sourceforge.net>
To: Oleg Lebedev <oleg.lebedev@waterford.org>
Cc: Josh Berkus <josh@agliodbs.com>
Cc: pgsql-performance@postgresql.org <pgsql-performance@postgresql.org>
Subject: Re: slow query
Date: 24 Feb 2003 11:58:33 -0500
Message-ID: <1046105913.1014.66.camel@camel> (raw)
In-Reply-To: <993DBE5B4D02194382EC8DF8554A5273033587@postoffice.waterford.org>
References: <993DBE5B4D02194382EC8DF8554A5273033587@postoffice.waterford.org>

On Mon, 2003-02-24 at 10:59, Oleg Lebedev wrote:
> Thanks everybody for your help.
> VACUUM FULL did the job, and now the query performance is the same in
> both databases. I am surprised that FULL option makes such a dramatic
> change to the query performance: from 4min. to 5sec.!!! It also changed
> planner stats from ~9 sec to ~8sec.

If your seeing wildly dramatic improvments from vacuum full, you might
want to look into running regular vacuums more often (especially for
high turnover tables), increase your max_fsm_relations to 1000, and
increasing your max_fsm_pages. 

Robert Treat





view thread (112+ messages)  latest in thread

Message-ID: <1046105913.1014.66.camel@camel>
Permalink:  ../1046105913.1014.66.camel@camel/
Also on:    postgresql.org/message-id/1046105913.1014.66.camel@camel

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: xzilla@users.sourceforge.net, oleg.lebedev@waterford.org, josh@agliodbs.com
  Subject: Re: slow query
  In-Reply-To: <1046105913.1014.66.camel@camel>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox